const IMAGES = [
  './assets/image1.png',
  './assets/image2.png',
  './assets/image3.png',
];

const STORAGE_KEY = 'dynamic_creative_last_index';

export class RotatingImages {
  constructor(container) {
    this.container = container;
    this.currentImage = '';

    // Register a listener for the cortex-visible event.
    window.addEventListener('cortex-visible', this.onVisible.bind(this));
  }

  // This method will get called when the dynamic creative is visible on the
  // screen. window.Cortex.* API will be available after we receive the
  // visibility event.
  onVisible() {
    console.warn('Dynamic creative is visible: ', window.Cortex);
  }

  start() {
    const img = document.createElement('img');
    img.src = this.getImage();
    this.container.appendChild(img);
  }

  getImage() {
    // Read the index from local storage.
    let index = localStorage.getItem(STORAGE_KEY);
    index = (index === null) ? -1 : Number(index);

    // Increment the index to find the next image to show.
    index = (index + 1) % IMAGES.length;

    this.currentImage = IMAGES[index];

    // Write back the index to local storage
    localStorage.setItem(STORAGE_KEY, index);

    return this.currentImage;
  }
}
