const path = require("path");
const webpack = require("webpack");

const CopyWebpackPlugin = require("copy-webpack-plugin");

const srcDir = path.resolve(__dirname, "src");
const assetsDir = path.resolve(__dirname, "assets");
const htmlDir = path.resolve(__dirname, "html");
const outDir = path.resolve(__dirname, "build");

const webpackConfig = {
  entry: path.resolve(srcDir, "main.js"),
  resolve: {
    modules: ["./node_modules"],
    extensions: [".js", ".ts"],
  },
  output: {
    path: outDir,
    publicPath: "/",
    filename: "bundle.js",
  },
  plugins: [
    new CopyWebpackPlugin({
      patterns: [
        { from: path.resolve(htmlDir, "index.html"), to: "index.html" },
        { from: assetsDir, to: "assets" },
      ],
    }),
    new webpack.NoEmitOnErrorsPlugin(),
  ],
  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: /node_modules/,
        use: {
          loader: "babel-loader?cacheDirectory=true",
          options: {
            cacheDirectory: true,
          },
        },
      },
      {
        test: /\.ts$/,
        loader: "ts-loader",
      },
    ],
  },
  stats: {
    colors: true,
  },
  devtool: "source-map",
  target: "web",
  cache: true,
};

module.exports = webpackConfig;
